require 'faker'

FactoryBot.define do
  factory :housing_request, class: Hermes::HousingRequest do
    trait :with_dependents do
      transient do
        dependents do
          [{
            "last_name" => "GOUBILL",
            "first_name" => "CHRIS",
            "birth_date" => "2017-03-23T00:00:00.000Z",
            "rel_type" => "E",
            "coparentality" => "G",
            "sex" => "M"
          },
          {
            "last_name" => "GOUBILL",
            "first_name" => "CHRIsdS",
            "birth_date" => "1990-03-23T00:00:00.000Z",
            "rel_type" => "E",
            "coparentality" => "G",
            "sex" => "M"
          },
          {
            "last_name" => "GOUBILLze",
            "first_name" => "CHRIS",
            "birth_date" => "2017-03-23T00:00:00.000Z",
            "rel_type" => "P",
            "sex" => "M"
          }]
        end
      end

      after :build do |req, evaluator|
        req.dependents = evaluator.dependents
      end
    end
  end

  factory :active_request, parent: :housing_request do
    is_active { true }
    association :main_applicant, factory: :applicant

    trait :with_applicants do
      transient do
        applicants_count { 3 }
      end
      after :build do |req, evaluator|
        evaluator.applicants_count.times { req.applicant_ids << create(:applicant).id }
      end
    end
  end
end